@@ -24,7 +24,7 @@ def copydoc(fromfunc):
         else:
             sourcedoc = fromfunc.__doc__
 
-        if func.__doc__ == None:
+        if func.__doc__ is None:
             func.__doc__ = sourcedoc
         else:
             func.__doc__ = f"{sourcedoc}\n\n{func.__doc__}"
