@@ -27,7 +27,6 @@ from .platform import (
     AnalysisRequestBase,
     AnalysisScope,
     ChallengeContent,
-    ChallengeSubmissionBase,
     ChallengeTaskBase,
     ConcernBase,
     DatasetBase,
@@ -46,6 +45,7 @@ from .platform import (
     PipelineBase,
     PipelineRunBase,
     ReportBase,
+    SubmissionBase,
     TagNameType,
     TeamBase,
     summary_maxlen,
@@ -149,9 +149,7 @@ class ChallengeCreateRequest(DyffEntityCreateRequest):
     )
 
 
-class ChallengeSubmissionCreateRequest(
-    DyffEntityCreateRequest, ChallengeSubmissionBase
-):
+class SubmissionCreateRequest(DyffEntityCreateRequest, SubmissionBase):
     pass
 
 
@@ -504,7 +502,6 @@ __all__ = [
     "ChallengeContentEditRequest",
     "ChallengeCreateRequest",
     "ChallengeQueryRequest",
-    "ChallengeSubmissionCreateRequest",
     "ChallengeTaskCreateRequest",
     "ChallengeTaskRulesEditRequest",
     "ChallengeTeamCreateRequest",
@@ -544,6 +541,7 @@ __all__ = [
     "ReportQueryRequest",
     "SafetyCaseQueryRequest",
     "ScoreQueryRequest",
+    "SubmissionCreateRequest",
     "TeamEditRequest",
     "TeamQueryRequest",
     "UseCaseQueryRequest",
